@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2015-09-28'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -842,7 +842,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.23 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-23.
+This document describes version 0.24 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-28.
 
 =head1 SYNOPSIS
 
@@ -869,22 +869,22 @@ B<EARLY DEVELOPMENT.>
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
                                    Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.376+-0.011/s            --               -60.2%       -82.3%         -88.5%                 -90.1%      -91.0% -97.5%
- run --version (lite)   33.641+-0.044/s 151.51+-0.39%                   --       -55.6%         -71.0%                 -75.0%      -77.4% -93.7%
- -c (lite)                75.77+-0.16/s   466.5+-1.3%        125.23+-0.55%           --         -34.7%                 -43.7%      -49.2% -85.8%
- run 1 (inline)          115.95+-0.63/s   766.9+-4.7%          244.7+-1.9% 53.03+-0.89%             --                 -13.9%      -22.3% -78.3%
- run --version (inline)    134.7+-1.8/s      907+-13%          300.4+-5.4%   77.8+-2.4%     16.2+-1.7%                     --       -9.7% -74.8%
- -c (inline)               149.1+-1.7/s     1015+-13%          343.3+-5.2%   96.8+-2.3%     28.6+-1.7%               10.7+-2%          -- -72.1%
- perl                        535+-7.2/s     3899+-54%            1490+-21%    606+-9.6%    361.4+-6.7%            297.2+-7.5% 258.7+-6.4%     --
+ run 1 (lite)           12.931+-0.013/s            --               -60.8%       -83.1%         -89.2%                 -91.5%      -93.8% -97.6%
+ run --version (lite)   33.016+-0.057/s 155.33+-0.51%                   --       -56.8%         -72.3%                 -78.3%      -84.1% -93.9%
+ -c (lite)                76.46+-0.24/s     491.3+-2%         131.6+-0.84%           --         -35.9%                 -49.8%      -63.2% -85.9%
+ run 1 (inline)          119.27+-0.44/s   822.4+-3.5%          261.3+-1.5% 55.99+-0.76%             --                 -21.7%      -42.6% -78.1%
+ run --version (inline)  152.26+-0.51/s  1077.5+-4.1%          361.2+-1.7% 99.12+-0.92%   27.65+-0.63%                     --      -26.7% -72.0%
+ -c (inline)             207.68+-0.88/s    1506.1+-7%            529+-2.9%  171.6+-1.4%   74.12+-0.97%            36.4+-0.73%          -- -61.8%
+ perl                        544+-2.5/s     4107+-20%         1547.6+-8.2%    611.4+-4%    356.1+-2.7%              257.3+-2% 161.9+-1.6%     --
  
  Average times:
-   perl                  :     1.8692ms
-   -c (inline)           :     6.7069ms
-   run --version (inline):     7.4239ms
-   run 1 (inline)        :     8.6244ms
-   -c (lite)             :    13.1978ms
-   run --version (lite)  :    29.7256ms
-   run 1 (lite)          :    74.7608ms
+   perl                  :     1.8382ms
+   -c (inline)           :     4.8151ms
+   run --version (inline):     6.5677ms
+   run 1 (inline)        :     8.3843ms
+   -c (lite)             :    13.0787ms
+   run --version (lite)  :    30.2883ms
+   run 1 (lite)          :    77.3335ms
 
 =head1 FUNCTIONS
 
